@@ -303,12 +303,15 @@ _gdk_win32_window_delete_property (GdkWindow *window,
   "Net/DoubleClickTime\0"     "gtk-double-click-time\0"
   "Net/DoubleClickDistance\0" "gtk-double-click-distance\0"
   "Net/DndDragThreshold\0"    "gtk-dnd-drag-threshold\0"
+  "Net/CursorBlink\0"         "gtk-cursor-blink\0"
+  "Net/CursorBlinkTime\0"     "gtk-cursor-blink-time\0"
   "Net/ThemeName\0"           "gtk-theme-name\0"
   "Net/IconThemeName\0"       "gtk-icon-theme-name\0"
   "Gtk/ColorPalette\0"        "gtk-color-palette\0"
   "Gtk/FontName\0"            "gtk-font-name\0"
   "Gtk/KeyThemeName\0"        "gtk-key-theme-name\0"
   "Gtk/Modules\0"             "gtk-modules\0"
+  "Gtk/CursorBlinkTimeout\0"  "gtk-cursor-blink-timeout\0"
   "Gtk/CursorThemeName\0"     "gtk-cursor-theme-name\0"
   "Gtk/CursorThemeSize\0"     "gtk-cursor-theme-size\0"
   "Gtk/ColorScheme\0"         "gtk-color-scheme\0"
@@ -386,7 +389,12 @@ _gdk_win32_screen_get_setting (GdkScreen   *screen,
       g_value_set_boolean (value, TRUE);
       return TRUE;
     }
-#if 0
+  else if (strcmp ("gtk-shell-shows-desktop", name) == 0)
+    {
+      GDK_NOTE(MISC, g_print("gdk_screen_get_setting(\"%s\") : TRUE\n", name));
+      g_value_set_boolean (value, TRUE);
+      return TRUE;
+    }
   /*
    * With 'MS Sans Serif' as windows menu font (default on win98se) you'll get a 
    * bunch of :
@@ -403,7 +411,7 @@ _gdk_win32_screen_get_setting (GdkScreen   *screen,
           /* Pango finally uses GetDeviceCaps to scale, we use simple
 	   * approximation here.
 	   */
-          int nHeight = (0 > ncm.lfMenuFont.lfHeight ? -3*ncm.lfMenuFont.lfHeight/4 : 10);
+          int nHeight = (0 > ncm.lfMenuFont.lfHeight ? - 3 * ncm.lfMenuFont.lfHeight / 4 : 10);
           if (OUT_STRING_PRECIS == ncm.lfMenuFont.lfOutPrecision)
             GDK_NOTE(MISC, g_print("gdk_screen_get_setting(%s) : ignoring bitmap font '%s'\n", 
                                    name, ncm.lfMenuFont.lfFaceName));
@@ -411,7 +419,7 @@ _gdk_win32_screen_get_setting (GdkScreen   *screen,
                    /* Avoid issues like those described in bug #135098 */
                    g_utf8_validate (ncm.lfMenuFont.lfFaceName, -1, NULL))
             {
-              char* s = g_strdup_printf ("%s %d", ncm.lfMenuFont.lfFaceName, nHeight);
+              char *s = g_strdup_printf ("%s %d", ncm.lfMenuFont.lfFaceName, nHeight);
               GDK_NOTE(MISC, g_print("gdk_screen_get_setting(%s) : %s\n", name, s));
               g_value_set_string (value, s);
 
@@ -420,7 +428,6 @@ _gdk_win32_screen_get_setting (GdkScreen   *screen,
             }
         }
     }
-#endif
 
   return FALSE;
 }
